from pyinspect.exceptions import install, print_exception

install()

from pyinspect.utils import print_function
from pyinspect.find import search
